menu
network_logger_custom package
documentation
network_event.dart
Headers class
Headers class
dark_mode
light_mode
Headers
class
Used for storing
Request
and
Response
headers.
Constructors
Headers
(
Iterable
<
MapEntry
<
String
,
String
>
>
entries
)
Headers.fromMap
(
Map
<
String
,
String
>
map
)
Properties
entries
→
List
<
MapEntry
<
String
,
String
>
>
final
hashCode
→
int
The hash code for this object.
no setter
inherited
isEmpty
→
bool
no setter
isNotEmpty
→
bool
no setter
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
getValue
(
String
key
)
→
String
?
Get value by key
map
<
T
>
(
T
cb
(
String
key
,
String
value
)
)
→
Iterable
<
T
>
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
network_logger_custom package
documentation
network_event
Headers class
network_event library