NetworkEventLog class

Network event log entry.

Constructors

NetworkEventLog({Request? request, Response? response, NetworkError? error, DateTime? requestTimestamp, DateTime? responseTimestamp})
NetworkEventLog.requestNow({Request? request, Response? response, NetworkError? error})
NetworkEventLog.responseNow({Request? request, Response? response, NetworkError? error, DateTime? requestTimestamp})

Properties

error NetworkError?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
request Request?
getter/setter pair
requestTimestamp DateTime?
getter/setter pair
response Response?
getter/setter pair
responseTimestamp DateTime?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited