Request class

Http request details.

Constructors

Request({required String uri, required String method, required Headers headers, dynamic data})

Properties

data → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
headers Headers
final
method String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited